@@ -31,6 +31,17 @@ R_CMethodDef CEntries[] = {
     {"mgcv_td_qy",(DL_FUNC)&mgcv_td_qy,7},
     {"rwMatrix",(DL_FUNC)&rwMatrix,6},
     {"in_out",(DL_FUNC)&in_out,8},
+    {"Rlanczos",(DL_FUNC)&Rlanczos,7},
+    {"rksos",(DL_FUNC)&rksos,3},
+    {"gen_tps_poly_powers",(DL_FUNC)&gen_tps_poly_powers,4},
+    {"sparse_penalty",(DL_FUNC)&sparse_penalty,9},
+    {"k_nn",(DL_FUNC)&k_nn,8},
+    {"kba_nn",(DL_FUNC)&kba_nn,9},
+    {"Rkdtree",(DL_FUNC)&Rkdtree,7},
+    {"sspl_construct",(DL_FUNC)&sspl_construct,9},
+    {"sspl_mapply",(DL_FUNC)&sspl_mapply,9},
+    {"tri2nei",(DL_FUNC)&tri2nei,5},
+    { "nei_penalty",(DL_FUNC)&nei_penalty, 10},
     {NULL, NULL, 0}
 };
 
