@@ -114,28 +114,6 @@ void RPackSarray(int m,matrix *S,double *RS)
 
 
 
-void RArrayFromMatrix(double *a,long r,matrix *M)
-
-/* copies matrix *M into R array a where r is the number of rows of A treated as
-  a matrix by R */
-
-{ int i,j;
-  for (i=0;i<M->r;i++) for (j=0;j<M->c;j++) a[i+r*j]=M->M[i][j];
-}
-
-
-matrix Rmatrix(double *A,long r,long c)
-
-/* produces a matrix from the array containing a (default) R matrix stored:
-   A[0,0], A[1,0], A[2,0] .... etc */
-
-{ int i,j;
-  matrix M;
-  M=initmat(r,c);
-  for (i=0;i<r;i++) for (j=0;j<c;j++) M.M[i][j]=A[i+j*r];
-  return(M);
-}
-
 
 /********** The following are from spline.c (rather plodding coding) ***********/
 
@@ -611,93 +589,6 @@ void construct_cr(double *x,int *nx,double *k,int *nk,double *X,double *S,double
   }
 } 
 
-void construct_tprs(double *x,int *d,int *n,double *knt,int *nk,int *m,int *k,double *X,double *S,
-                    double *UZ,double *Xu,int *nXu,double *C)
-/* inputs: 
-   x contains the n values of each of the d covariates, stored end to end
-   knt contains the nk knot locations packed as x
-   m is the order of the penalty 
-   k is the basis dimension
-   max_knots is the maximum number of knots to allow in t.p.r.s. setup.   
-
-   outputs:
-   X is the n by k model matrix
-   S is the K by K penalty matrix
-   UZ is the (nXu+M) by k matrix transforming from the truncated to full bases
-   Xu is the nXu by d matrix of unique covariate combinations
-   C is the 1 by k sum to zero constraint matrix 
-*/ 
-
-{ double **xx,**kk=NULL,*dum,**XM;
-  matrix Xm,Sm,UZm,Xum;
-  int i,j,Xr;
-  xx=(double **)calloc((size_t)(*d),sizeof(double*));
-  for (i=0;i<*d;i++) xx[i]=x + i * *n;
-  if (*nk)
-  { kk=(double **)calloc((size_t)(*d),sizeof(double*));
-    for (i=0;i<*d;i++) kk[i]=knt + i * *nk;
-  }
-  tprs_setup(xx,kk,*m,*d,*n,*k,1,&Xm,&Sm,&UZm,&Xum,*nk); /* Do actual setup */
-  RArrayFromMatrix(X,Xm.r,&Xm);
-  RArrayFromMatrix(S,Sm.r,&Sm);
-  RArrayFromMatrix(UZ,UZm.r,&UZm);  
-  RArrayFromMatrix(Xu,Xum.r,&Xum);
-  *nXu=Xum.r;  
-  /* construct the sum to zero constraint */
-  dum=C;XM=Xm.M;Xr=Xm.r;
-  for (i=0;i< *k;i++)
-  { *dum = 0.0;
-    for (j=0;j<Xr;j++) *dum += XM[j][i];
-    dum++;
-  }
-  freemat(Xm);freemat(Sm);freemat(UZm);freemat(Xum);
-  free(xx);if(*nk) free(kk);
-}
-
-void predict_tprs(double *x, int *d,int *n,int *m,int *k,int *M,double *Xu,int *nXu,
-                  double *UZ,double *by,int *by_exists,double *X)
-/* inputs are:
-   * The n values of the d covariates at which to predict - covariates packed end to end in x
-     - any required centering to be done before this call.
-   * m is the penalty order and M the null space dimension
-   * k is the rank of the basis
-   * Xu is the nXu by d matrix of unique covariate values
-   * UZ is the basis of the reduced space 
-
-   returns the n by k matrix X mapping the parameters to the predicted values.
-*/
-{ matrix Xm,UZm,Xum,b,p;
-  double by_mult,*xx;
-  int i,j,l;
-  p.r=0L;
-  Xum=Rmatrix(Xu,*nXu,*d);
-  UZm=Rmatrix(UZ,*nXu + *M,*k);
-  b=initmat(UZm.r,1L);
-  Xm=initmat((long)*n,(long)*k);
-  xx=(double*)calloc((size_t) *d,sizeof(double));
-  for (i=0;i< *n;i++) 
-  { if (*by_exists) by_mult=by[i]; else by_mult=1.0;
-    if (by_mult==0.0)         /* then don't waste flops on calculating stuff that will only be zeroed */
-    { for (j=0;j<UZm.c;j++) Xm.M[i][j]=0.0;
-    } else                    /* proceed as normal */
-    { for (j=0;j< *d;j++) xx[j]=x[j * *n + i];
-      tps_g(&Xum,&p,xx,*d,*m,&b,1);             
-      for (j=0;j<UZm.c;j++) 
-      { Xm.M[i][j]=0.0;
-        for (l=0;l<b.r;l++) Xm.M[i][j] += b.V[l]*UZm.M[l][j]; /* forming b'UZ */
-        Xm.M[i][j] *= by_mult;
-      }
-    }
-  }
-  /* Now clean up and copy X back.*/
-  RArrayFromMatrix(X,Xm.r,&Xm);
-  tps_g(&Xum,&p,x,0,0,&b,1); /* have tps_g clear up */ 
-  freemat(Xm);freemat(Xum);freemat(UZm);freemat(b);
-  free(xx);
-}
-
-
-
 
 
 
@@ -1056,6 +947,29 @@ void RMonoCon(double *Ad,double *bd,double *xd,int *control,double *lower,double
 }
 
 
+void Rlanczos1(double *A,double *U,double *D,int *n, int *m, int *lm) {
+/* interface to lanczos_spd for calling from R.
+   A is n by n symmetric matrix. Let k = m + max(0,lm).
+   U is n by k and D is a k-vector.
+   m is the number of upper eigenvalues required and lm the number of lower.
+   If lm<0 then the m largest magnitude eigenvalues (and their eigenvectors)
+   are returned. Superceded. See Rlanczos in matrix.c. 
+*/
+  matrix Am,V,va;  
+  int k;
+  Am = Rmatrix(A,*n,*n);
+  k = *m;if (*lm>0) k += *lm;
+  V = initmat(*n,k);
+  va = initmat(k,1);
+  k = lanczos_spd(&Am,&V,&va,*m,*lm);
+  RArrayFromMatrix(U,*n,&V);
+  RArrayFromMatrix(D,k,&va);
+  freemat(va);freemat(V);freemat(Am);
+  *n = k; /* number of iterations taken */
+}
+
+
+
 void RQT(double *A,int *r,int*c)
 
 /* Obtains the QT decomposition of matrix A (stored according to R conventions)
